pub fn medium_capabilities(medium_type: MediumType) -> MediumCapabilitiesExpand description
The capability-matrix row for a medium type. The single source of truth the fidelity report also renders.
pub fn medium_capabilities(medium_type: MediumType) -> MediumCapabilitiesThe capability-matrix row for a medium type. The single source of truth the fidelity report also renders.