pub enum ResolveError {
BindingNotFound {
name: String,
available: Vec<String>,
},
MalformedProjectionRef {
ingest: String,
projection: String,
},
}Expand description
Why a binding could not be resolved. With inline sources the only structural failures left are identity-level: an unknown binding id, or a malformed one.
Variants
BindingNotFound
No binding with the given id in the store.
MalformedProjectionRef
The binding id is not the required "<mem>/<name>".