graph_changes_to_slice

Function graph_changes_to_slice 

pub fn graph_changes_to_slice(changes: &[ChangeEnvelope]) -> Slice
Map a graph mem’s change envelopes into a Slice of entity ids: Removed → deleted; Renamed → the new id added and the old id deleted; Added → added; Updated → modified.