compute_shape

Function compute_shape 

pub fn compute_shape(
    store: &Store,
    start: &EntityId,
    walk: &SupportWalk,
    label_of: &dyn Fn(&EntityId) -> Option<Label>,
) -> ShapeStats
Walk the support subtree from start and compute the shape statistics. label_of resolves a subtree node’s label (nodes of mems without a labelling declaration resolve to None and count toward neither label count).