pub struct UpdatedRef {
pub ref_name: String,
pub previous_sha: String,
pub new_sha: String,
}Expand description
One ref’s transition recorded by a successful fetch / pull.
Fields
ref_name: StringRef name (e.g. refs/remotes/origin/specs).
previous_sha: StringSHA the ref pointed at before this op, when known. Empty string when the ref did not exist locally before the op.
new_sha: StringSHA the ref points at after this op.