pub fn medium_capabilities(medium_type: MediumType) -> MediumCapabilitiesExpand description
The capability-matrix row for a medium type (D6). The single source of truth the fidelity report (E3b) will also render.
pub fn medium_capabilities(medium_type: MediumType) -> MediumCapabilitiesThe capability-matrix row for a medium type (D6). The single source of truth the fidelity report (E3b) will also render.