write_entity

Function write_entity 

pub fn write_entity(
    entity: &Entity,
    mem_dir: &Path,
    schema: &TypeDefinition,
) -> Result<PathBuf, WriteError>
Write an entity to its file path under the mem directory. Creates parent directories as needed. Returns the absolute path where the file was written.